@@ -447,6 +447,23 @@ def ship(components: "Component codes",
         logger.info(
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
 
+def testresult(tid: "Test ID",
+             returnResults: "Return lookup results (useful if not used from CLI)" = False,
+             printJSON: "PrettyPrint the component JSON" = False):
+    "Look up a test result for a given test ID."
+    try:
+        logger.info(f"Looking up tests TID = {tid}")
+        client = itkdb.Client()
+        result = client.get('getTestRun', json={'testRun': tid})
+        if printJSON:
+            print(json.dumps(result, indent=1))
+        if returnResults or __name__ != '__main__':
+            return result
+    except Exception as e:
+        logger.error(e)
+        logger.error("Error while trying to get connection to DB")
+        logger.info(
+            "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
 
 def main():
     parser = argh.ArghParser()
@@ -454,7 +471,7 @@ def main():
                         attach, tests, stage,
                         skeleton, upload, testruns,
                         testfile, assemble, property,
-                        comment, ship])
+                        comment, ship, testresult])
     parser.dispatch()
 
 
